==> elisa-0.3.0.tar.xz: elisa-0.3.0/src/models/singlealbumproxymodel.h <==
/*
 * Copyright 2017 Alexander Stippich <a.stippich@gmx.net>
 * Copyright 2018 Matthieu Gallien <matthieu_gallien@yahoo.fr>
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef SINGLEALBUMPROXYMODEL_H
#define SINGLEALBUMPROXYMODEL_H

#include "elisaLib_export.h"

#include "abstractmediaproxymodel.h"
#include "musicaudiotrack.h"
#include "elisautils.h"
#include "albummodel.h"

class ELISALIB_EXPORT SingleAlbumProxyModel : public AbstractMediaProxyModel
{
    Q_OBJECT

public:

    explicit SingleAlbumProxyModel(QObject *parent = nullptr);

    ~SingleAlbumProxyModel() override;

Q_SIGNALS:

    void trackToEnqueue(QList<MusicAudioTrack> newTracks,
                        ElisaUtils::PlayListEnqueueMode enqueueMode,
                        ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay);

public Q_SLOTS:

    void enqueueToPlayList();

    void replaceAndPlayOfPlayList();

    void loadAlbumData(qulonglong databaseId);

protected:

    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;

};

#endif // SINGLEALBUMPROXYMODEL_H

==> elisa-0.4.1.tar.xz: elisa-0.4.1/src/models/singlealbumproxymodel.h <==
/*
 * Copyright 2017 Alexander Stippich <a.stippich@gmx.net>
 * Copyright 2018 Matthieu Gallien <matthieu_gallien@yahoo.fr>
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef SINGLEALBUMPROXYMODEL_H
#define SINGLEALBUMPROXYMODEL_H

#include "elisaLib_export.h"

#include "abstractmediaproxymodel.h"
#include "musicaudiotrack.h"
#include "elisautils.h"

class ELISALIB_EXPORT SingleAlbumProxyModel : public AbstractMediaProxyModel
{
    Q_OBJECT

public:

    explicit SingleAlbumProxyModel(QObject *parent = nullptr);

    ~SingleAlbumProxyModel() override;

Q_SIGNALS:

    void entriesToEnqueue(const ElisaUtils::EntryDataList &newEntries,
                          ElisaUtils::PlayListEntryType databaseIdType,
                          ElisaUtils::PlayListEnqueueMode enqueueMode,
                          ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay);

public Q_SLOTS:

    void enqueueToPlayList();

    void replaceAndPlayOfPlayList();

protected:

    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;

private:

    void genericEnqueueToPlayList(ElisaUtils::PlayListEnqueueMode enqueueMode,
                                  ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay);

};

#endif // SINGLEALBUMPROXYMODEL_H
